# Usage Example

from enstools.feature.pipeline import FeaturePipeline
from enstools.feature.identification.template import IdentificationTemplate
from enstools.feature.tracking.template_object_compare import TrackingCompareTemplate
from enstools.feature.tracking.template import TrackingTemplate
from enstools.feature.identification._proto_gen import template_pb2
from os.path import expanduser
from enstools.feature.util.graph import DataGraph

# set the pb_reference to the compiled pb2.py file (see proto_gen directory)
pipeline = FeaturePipeline(template_pb2, processing_mode='2d')

# change this to an identification technique that actually does something: existing one or implement your own
i_strat = IdentificationTemplate(some_parameter='foo') # set the Identification strategy
t_strat = TrackingCompareTemplate() # set the tracking strategy

pipeline.set_identification_strategy(i_strat)
pipeline.set_tracking_strategy(t_strat) # or None as argument if no tracking

path = expanduser("~") + '/phd/data/tracked/feature/enstools_feature_test.nc' #  ERA5/vietnam/t0_glob.nc' #  set data path(s) here
pipeline.set_data_path(path)

# execute pipeline
pipeline.execute()

od = pipeline.get_object_desc()

for trackable_set in od.sets:
    # generate graph out of tracked data
    g = DataGraph(set_desc=trackable_set, tr_tech=t_strat)

    # generate single tracks from tracked data
    # returns list of tracks, also gets added to object description.
    # Also if apply_filter, keep_track() gets called for every track, a method of TrackingTechnique, which can be overwritten.
    print("GENERATE TRACKS...")
    g.generate_tracks(apply_filter=True)
    tracks = g.set_desc.tracks

    # can perform operations on tracks and nodes...
    track = DataGraph(track=tracks[0])

    # get earliest and latest nodes of that track
    earliest_nodes = track.get_earliest_nodes()
    print("First nodes:")
    print([en.time + " ID " + str(en.object.id) for en in earliest_nodes])
    latest_nodes = track.get_latest_nodes()
    print("Latest nodes:")
    print([ln.time + " ID " + str(ln.object.id) for ln in latest_nodes])

    if len(latest_nodes):
        parents = track.get_parents(latest_nodes[0])
        print("Parents of a latest node:")
        print([p.time + " ID " + str(p.object.id) for p in parents])
        childs = track.get_childs(latest_nodes[0])
        print("Childs of latest nodes:")
        print([c.time + " ID " + str(c.object.id) for c in childs])


    for track_id, track in enumerate(tracks):
        print("Track " + str(track_id) + " has " + str(len(DataGraph(track=track).graph.edges)) + " nodes.")


out_json_path = path[:-3] + '_desc.json'
out_graph_path = path[:-3] + '_graph.json'

pipeline.save_result(description_type='json', description_path=out_json_path) # dataset_path=...


